*** THIS DO-FILE COMPARES TWO TAX REGIMES, REFERRED TO AS "BEFORE REFORM" (`t') AND "AFTER REFORM" (`u') 
*** Computes the diffs in taxes and benefits, and diffs in characteristics, between the two tax regimes
*** Files needed for this do-file: taxbenchars_`t' and taxbenchars_`u', 
*** .. as generated either by etbrun or etbreform
*** Naming convention: "after reform" regime comes first in suffixes, e.g. tax_`u' - tax`t' = tax_`u'_`t'

capture clear matrix
clear 
set more off
set memory 512m

* Define the program
capture program drop reformcompare
program define reformcompare
args u t 
	
	capture mkdir output_`u'_`t'
	
	* Create a merged dataset
	use output_`u'/taxbenchars_`u'
	capture drop _merge
	save output_`u'_`t'/taxbenchars_`u'_`t', replace
	sort domac osoba
	merge 1:1 domac osoba using output_`t'/taxbenchars_`t', gen(_mergechars)
	sort domac osoba
	cd output_`u'_`t'
	save taxbenchars_`u'_`t', replace

	* Generate differences between variables between the two regimes
	* This is done by a simple program (reformdiff) because it is always the same
	* The program reformdiff is defined below
	* The argument of the program is a local macro (a list of variables to be differenced)
	
	* Run the program for different set of variables to keep it organized:
	
	* Individual taxes
	* Note: the list of taxes can be expanded (break down the payroll taxes into formal and informal work, main and secondary business, social security and health...)
	reformdiff `u' `t' "ssp_w ssp_b ssp_i healthp_w healthp_b healthp_i payrolltaxer_w payrolltaxee_w payrolltax_w payrolltax_b inctax_w inctax_b inctax_i totaltax_w totaltax_b totaltax_i"
	
	* Household taxes and benefits per unit
	reformdiff `u' `t' "hhtotaltax_pos hhtotalben_pos hhnettax_pos hhtotaltax_perunit2 hhtotalben_perunit2 hhnettax_perunit2 hhtotaltax2_i hhtotalben2 hhnettax2 hhtotaltax_perunit hhtotalben_perunit hhnettax_perunit hhaftertinc_perunit hhbeninc_perunit hhnetinc_perunit"
		
	* Household total taxes and benefits
	reformdiff `u' `t' "hhtotaltax_w hhtotaltax_b hhtotaltax_i hhtotalben hhnettax_i hhaftertinc hhbeninc hhnetinc"
	
	* Individual net income
	reformdiff `u' `t' "netinc" 
	
	* Individual tax characteristics - ATR's
	reformdiff `u' `t' "ATR_w ATR_b ATR_i"
	
	* Individual tax characteristics - MTR's 
	reformdiff `u' `t' "mtr_tax_w mtr_tax_b mtr_tax_i mtr_ben_i mtr_all_w mtr_all_b mtr_all_i"
	
	* Individual tax characteristics - PTR's 
	reformdiff `u' `t' "ptr_tax_w ptr_ben_w ptr_all_w ptr_tax_b ptr_ben_b ptr_all_b ptr_tax_i ptr_ben_i ptr_all_i ptr_tax_w_f ptr_tax_w_p ptr_ben_w_f ptr_ben_w_p ptr_all_w_f ptr_all_w_p"
	
	* Household tax and benefit characteristics
	reformdiff `u' `t' "hhATR_tax hhATR_ben hhATR_all"
	
	* PERCENTAGE change in household-level variables
	reformdiffp `u' `t' "hhnetinc"
	
	* Distributional characteristics - decile shares - individuals
	reformdiff `u' `t' "dec_shr_totaltax_w dec_shr_totaltax_b dec_shr_totaltax_i"
	
	* Distributional characteristics - decile shares - households
	reformdiff `u' `t' "dec_shr_hhtotaltax dec_shr_hhtotalben dec_shr_hhnettax"
	
	* Tax revenues
	reformdiff `u' `t' "rev_inctax_w rev_inctax_b rev_inctax_i rev_ssp_w rev_ssp_b rev_ssp_i rev_healthp_w rev_healthp_b rev_healthp_i rev_totaltax_w rev_totaltax_b rev_totaltax_i"
		
	* Benefit expenditures
	reformdiff `u' `t' "exp_brth_gr exp_mat_ben exp_mat_need exp_ch_all exp_hous_ben exp_liv_all exp_hous_supl exp_unempl_ben exp_par_all exp_other_ben"
		
	***Cutting tails for plotting
	*** some very extreme values of changes ATR or MTR, PTR due to particular circumstances (??? or errors?) - isolate them out
	*** keep only people above the 1st and below 98th percentile of the change in the ATR, MTR, PTR - we do it for levels as well
	local cutvars "ATR_w ATR_b ATR_i hhATR_ben hhATR_tax hhATR_all mtr_tax_w mtr_all_w mtr_tax_b mtr_all_b mtr_tax_i mtr_ben_i mtr_all_i ptr_tax_w_f ptr_tax_w_p ptr_tax_w ptr_ben_w_f ptr_ben_w_p ptr_ben_w ptr_all_w_f ptr_all_w_p ptr_all_w ptr_tax_b ptr_ben_b ptr_all_b ptr_tax_i ptr_ben_i ptr_all_i"
	foreach v of local cutvars {
		centile `v'_`u'_`t', centile(1 99)
		scalar `v'low = r(c_1)
		scalar `v'high = r(c_2)  
		gen p`v'_`u'_`t' = `v'_`u'_`t' if (`v'_`u'_`t' >=`v'low & `v'_`u'_`t' <= `v'high) | abs(`v'_`u'_`t')<1.01
	}
	
	save taxbenchars_`u'_`t', replace
	cd ..
	
	* Distributional characteristics - tax rate interval shares
	* The resulting difference is the change in the share of people (or incomes) in a given tax interval
	* Compute for taxpayer shares and income shares
	* The intervals are stored away in separate datasets (wintervals_`t') that must be merged first
	
	use output_`u'/wintervals_`u'
	capture drop _merge
	save output_`u'_`t'/wintervals_`u'_`t', replace
	sort int_taxrate
	merge 1:1 int_taxrate using output_`t'/wintervals_`t', gen(_mergeint)
	sort int_taxrate
	save output_`u'_`t'/wintervals_`u'_`t', replace
		
	* Distributional characteristics - tax rate interval shares - individual ATRs and MTRs'
	reformdiff `u' `t' "shrn_ATR_w shrn_ATR_b shrn_ATR_i shrn_mtr_tax_w shrn_mtr_tax_b shrn_mtr_tax_i shrn_mtr_ben_i shrn_mtr_all_w shrn_mtr_all_b shrn_mtr_all_i"
	reformdiff `u' `t' "shri_ATR_w shri_ATR_b shri_ATR_i shri_mtr_tax_w shri_mtr_tax_b shri_mtr_tax_i shri_mtr_ben_i shri_mtr_all_w shri_mtr_all_b shri_mtr_all_i"
	
	* Distributional characteristics - tax rate interval shares - individual PTR's 
	reformdiff `u' `t' "shrn_ptr_tax_w shrn_ptr_ben_w shrn_ptr_all_w shrn_ptr_tax_b shrn_ptr_ben_b shrn_ptr_all_b shrn_ptr_tax_i shrn_ptr_ben_i shrn_ptr_all_i shrn_ptr_tax_w_f shrn_ptr_ben_w_f shrn_ptr_all_w_f shrn_ptr_tax_w_p shrn_ptr_ben_w_p shrn_ptr_all_w_p"
	reformdiff `u' `t' "shri_ptr_tax_w shri_ptr_ben_w shri_ptr_all_w shri_ptr_tax_b shri_ptr_ben_b shri_ptr_all_b shri_ptr_tax_i shri_ptr_ben_i shri_ptr_all_i shri_ptr_tax_w_f shri_ptr_ben_w_f shri_ptr_all_w_f shri_ptr_tax_w_p shri_ptr_ben_w_p shri_ptr_all_w_p"
	
	* Distributional characteristics - tax rate interval shares - households
	reformdiff `u' `t' "shrn_hhATR_tax shrn_hhATR_ben shrn_hhATR_all"
	reformdiff `u' `t' "shri_hhATR_tax shri_hhATR_ben shri_hhATR_all"
	
	save output_`u'_`t'/wintervals_`u'_`t', replace
	
end // end program reformcompare
	
* Define the subprogram "reformdiff" that generates the differences. 
* The argument of the program is a local macro (a list of variables to be differenced)

capture program drop reformdiff
program define reformdiff
	args u t diffvars
	foreach x of local diffvars {
		g `x'_`u'_`t' = `x'_`u' - `x'_`t'
		label var `x'_`u'_`t' "Difference in `x' between tax regimes `u' and `t'"
	}
end //end subprogram reformdiff

* Define the subprogram "reformdiffp" that generates PERCENTAGE differences of the variables
* This is used (so far) only to compute the percentage change in the household net income
capture program drop reformdiffp
program define reformdiffp
	args u t diffvars
	foreach x of local diffvars {
		g pd_`x'_`u'_`t' = (`x'_`u'-`x'_`t')/`x'_`t'
		label var pd_`x'_`u'_`t' "Percentage difference in `x' between tax regimes `u' and `t'" 
	}
end // end subprogram reformdiffp




